==> MediaWikiLanguageExtensionBundle-2017.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesEn_ca.php <==
<?php

$currencyNames = [
	'ILS' => 'Israeli new sheqel',
];

$timeUnits = [
	'fri-narrow-future-one' => 'in {0} F',
	'fri-narrow-future-other' => 'in {0} F’s',
	'fri-narrow-past-one' => '{0} F ago',
	'fri-narrow-past-other' => '{0} F’s ago',
	'fri-short-future-one' => 'in {0} Fri.',
	'fri-short-future-other' => 'in {0} Fri’s.',
	'fri-short-past-one' => '{0} Fri. ago',
	'fri-short-past-other' => '{0} Fri’s. ago',
	'hour-short-future-one' => 'in {0} hr.',
	'hour-short-future-other' => 'in {0} hrs.',
	'hour-short-past-one' => '{0} hr. ago',
	'hour-short-past-other' => '{0} hrs. ago',
	'minute-short-future-one' => 'in {0} min.',
	'minute-short-future-other' => 'in {0} mins.',
	'minute-short-past-one' => '{0} min. ago',
	'minute-short-past-other' => '{0} mins. ago',
	'mon-narrow-future-one' => 'in {0} M',
	'mon-narrow-future-other' => 'in {0} M’s',
	'mon-narrow-past-one' => '{0} M ago',
	'mon-narrow-past-other' => '{0} M’s ago',
	'mon-short-future-one' => 'in {0} Mon.',
	'mon-short-future-other' => 'in {0} Mon’s.',
	'mon-short-past-one' => '{0} Mon. ago',
	'mon-short-past-other' => '{0} Mon’s. ago',
	'month-narrow-future-one' => 'in {0} mo.',
	'month-narrow-future-other' => 'in {0} mos.',
	'month-narrow-past-one' => '{0} mo. ago',
	'month-narrow-past-other' => '{0} mos. ago',
	'month-short-future-one' => 'in {0} mo.',
	'month-short-future-other' => 'in {0} mos.',
	'month-short-past-one' => '{0} mo. ago',
	'month-short-past-other' => '{0} mos. ago',
	'quarter-narrow-future-one' => 'in {0} qtr.',
	'quarter-narrow-future-other' => 'in {0} qtr.',
	'quarter-narrow-past-one' => '{0} qtr. ago',
	'quarter-narrow-past-other' => '{0} qtr. ago',
	'sat-narrow-future-one' => 'in {0} Sa',
	'sat-narrow-future-other' => 'in {0} Sa’s',
	'sat-narrow-past-one' => '{0} Sa ago',
	'sat-narrow-past-other' => '{0} Sa’s ago',
	'sat-short-future-one' => 'in {0} Sat.',
	'sat-short-future-other' => 'in {0} Sat’s.',
	'sat-short-past-one' => '{0} Sat. ago',
	'sat-short-past-other' => '{0} Sat’s. ago',
	'second-short-future-one' => 'in {0} sec.',
	'second-short-future-other' => 'in {0} secs.',
	'second-short-past-one' => '{0} sec. ago',
	'second-short-past-other' => '{0} secs. ago',
	'sun-narrow-future-one' => 'in {0} Su',
	'sun-narrow-future-other' => 'in {0} Su’s',
	'sun-narrow-past-one' => '{0} Su ago',
	'sun-narrow-past-other' => '{0} Su’s ago',
	'sun-short-future-one' => 'in {0} Sun.',
	'sun-short-future-other' => 'in {0} Sun’s.',
	'thu-narrow-future-one' => 'in {0} Th',
	'thu-narrow-future-other' => 'in {0} Th’s',
	'thu-narrow-past-one' => '{0} Th ago',
	'thu-narrow-past-other' => '{0} Th’s ago',
	'thu-short-future-one' => 'in {0} Thu.',
	'thu-short-future-other' => 'in {0} Thu’s.',
	'thu-short-past-one' => '{0} Thu. ago',
	'thu-short-past-other' => '{0} Thu’s ago',
	'tue-narrow-future-one' => 'in {0} Tu',
	'tue-narrow-future-other' => 'in {0} Tu’s',
	'tue-narrow-past-one' => '{0} Tu ago',
	'tue-narrow-past-other' => '{0} Tu’s ago',
	'tue-short-future-one' => 'in {0} Tue.',
	'tue-short-future-other' => 'in {0} Tue’s.',
	'tue-short-past-one' => '{0} Tue. ago',
	'tue-short-past-other' => '{0} Tue’s. ago',
	'wed-narrow-future-one' => 'in {0} W',
	'wed-narrow-future-other' => 'in {0} W’s',
	'wed-narrow-past-one' => '{0} W ago',
	'wed-narrow-past-other' => '{0} W’s ago',
	'wed-short-future-one' => 'in {0} Wed.',
	'wed-short-future-other' => 'in {0} Wed’s.',
	'wed-short-past-one' => '{0} Wed. ago',
	'wed-short-past-other' => '{0} Wed’s. ago',
	'week-short-future-one' => 'in {0} wk.',
	'week-short-future-other' => 'in {0} wks.',
	'week-short-past-one' => '{0} wk. ago',
	'week-short-past-other' => '{0} wks. ago',
	'year-short-future-one' => 'in {0} yr.',
	'year-short-future-other' => 'in {0} yrs.',
	'year-short-past-one' => '{0} yr. ago',
	'year-short-past-other' => '{0} yrs. ago',
];

==> MediaWikiLanguageExtensionBundle-2018.01.tar.bz2: extensions/cldr/CldrNames/CldrNamesEn_ca.php <==
<?php

$languageNames = [
	'bn' => 'Bengali',
	'mfe' => 'Mauritian',
	'ro-md' => 'Moldovan',
	'tvl' => 'Tuvaluan',
];

$currencyNames = [
	'ILS' => 'Israeli new sheqel',
];

$timeUnits = [
	'fri-narrow-future-one' => 'in {0} F',
	'fri-narrow-future-other' => 'in {0} F’s',
	'fri-narrow-past-one' => '{0} F ago',
	'fri-narrow-past-other' => '{0} F’s ago',
	'fri-short-future-one' => 'in {0} Fri.',
	'fri-short-future-other' => 'in {0} Fri’s.',
	'fri-short-past-one' => '{0} Fri. ago',
	'fri-short-past-other' => '{0} Fri’s. ago',
	'hour-narrow-future-one' => 'in {0} hr.',
	'hour-narrow-future-other' => 'in {0} hrs.',
	'hour-narrow-past-one' => '{0} hr. ago',
	'hour-narrow-past-other' => '{0} hrs. ago',
	'hour-short-future-one' => 'in {0} hr.',
	'hour-short-future-other' => 'in {0} hrs.',
	'hour-short-past-one' => '{0} hr. ago',
	'hour-short-past-other' => '{0} hrs. ago',
	'minute-narrow-future-one' => 'in {0} min.',
	'minute-narrow-future-other' => 'in {0} mins.',
	'minute-narrow-past-one' => '{0} min. ago',
	'minute-narrow-past-other' => '{0} mins. ago',
	'minute-short-future-one' => 'in {0} min.',
	'minute-short-future-other' => 'in {0} mins.',
	'minute-short-past-one' => '{0} min. ago',
	'minute-short-past-other' => '{0} mins. ago',
	'mon-narrow-future-one' => 'in {0} M',
	'mon-narrow-future-other' => 'in {0} M’s',
	'mon-narrow-past-one' => '{0} M ago',
	'mon-narrow-past-other' => '{0} M’s ago',
	'mon-short-future-one' => 'in {0} Mon.',
	'mon-short-future-other' => 'in {0} Mon’s.',
	'mon-short-past-one' => '{0} Mon. ago',
	'mon-short-past-other' => '{0} Mon’s. ago',
	'month-narrow-future-one' => 'in {0} mo.',
	'month-narrow-future-other' => 'in {0} mos.',
	'month-narrow-past-one' => '{0} mo. ago',
	'month-narrow-past-other' => '{0} mos. ago',
	'month-short-future-one' => 'in {0} mo.',
	'month-short-future-other' => 'in {0} mos.',
	'month-short-past-one' => '{0} mo. ago',
	'month-short-past-other' => '{0} mos. ago',
	'quarter-narrow-future-one' => 'in {0} qtr.',
	'quarter-narrow-future-other' => 'in {0} qtrs.',
	'quarter-narrow-past-one' => '{0} qtr. ago',
	'quarter-narrow-past-other' => '{0} qtrs. ago',
	'quarter-short-future-one' => 'in {0} qtr.',
	'quarter-short-future-other' => 'in {0} qtrs.',
	'quarter-short-past-one' => '{0} qtr. ago',
	'quarter-short-past-other' => '{0} qtrs. ago',
	'sat-narrow-future-one' => 'in {0} Sa',
	'sat-narrow-future-other' => 'in {0} Sa’s',
	'sat-narrow-past-one' => '{0} Sa ago',
	'sat-narrow-past-other' => '{0} Sa’s ago',
	'sat-short-future-one' => 'in {0} Sat.',
	'sat-short-future-other' => 'in {0} Sat’s.',
	'sat-short-past-one' => '{0} Sat. ago',
	'sat-short-past-other' => '{0} Sat’s. ago',
	'second-narrow-future-one' => 'in {0} sec.',
	'second-narrow-future-other' => 'in {0} secs.',
	'second-narrow-past-one' => '{0} sec. ago',
	'second-narrow-past-other' => '{0} secs. ago',
	'second-short-future-one' => 'in {0} sec.',
	'second-short-future-other' => 'in {0} secs.',
	'second-short-past-one' => '{0} sec. ago',
	'second-short-past-other' => '{0} secs. ago',
	'sun-narrow-future-one' => 'in {0} Su',
	'sun-narrow-future-other' => 'in {0} Su’s',
	'sun-narrow-past-one' => '{0} Su ago',
	'sun-narrow-past-other' => '{0} Su’s ago',
	'sun-short-future-one' => 'in {0} Sun.',
	'sun-short-future-other' => 'in {0} Sun’s.',
	'thu-narrow-future-one' => 'in {0} Th',
	'thu-narrow-future-other' => 'in {0} Th’s',
	'thu-narrow-past-one' => '{0} Th ago',
	'thu-narrow-past-other' => '{0} Th’s ago',
	'thu-short-future-one' => 'in {0} Thu.',
	'thu-short-future-other' => 'in {0} Thu’s.',
	'thu-short-past-one' => '{0} Thu. ago',
	'thu-short-past-other' => '{0} Thu’s ago',
	'tue-narrow-future-one' => 'in {0} Tu',
	'tue-narrow-future-other' => 'in {0} Tu’s',
	'tue-narrow-past-one' => '{0} Tu ago',
	'tue-narrow-past-other' => '{0} Tu’s ago',
	'tue-short-future-one' => 'in {0} Tue.',
	'tue-short-future-other' => 'in {0} Tue’s.',
	'tue-short-past-one' => '{0} Tue. ago',
	'tue-short-past-other' => '{0} Tue’s. ago',
	'wed-narrow-future-one' => 'in {0} W',
	'wed-narrow-future-other' => 'in {0} W’s',
	'wed-narrow-past-one' => '{0} W ago',
	'wed-narrow-past-other' => '{0} W’s ago',
	'wed-short-future-one' => 'in {0} Wed.',
	'wed-short-future-other' => 'in {0} Wed’s.',
	'wed-short-past-one' => '{0} Wed. ago',
	'wed-short-past-other' => '{0} Wed’s. ago',
	'week-narrow-future-one' => 'in {0} wk.',
	'week-narrow-future-other' => 'in {0} wks.',
	'week-narrow-past-one' => '{0} wk. ago',
	'week-narrow-past-other' => '{0} wks. ago',
	'week-short-future-one' => 'in {0} wk.',
	'week-short-future-other' => 'in {0} wks.',
	'week-short-past-one' => '{0} wk. ago',
	'week-short-past-other' => '{0} wks. ago',
	'year-narrow-future-one' => 'in {0} yr.',
	'year-narrow-future-other' => 'in {0} yrs.',
	'year-narrow-past-one' => '{0} yr. ago',
	'year-narrow-past-other' => '{0} yrs. ago',
	'year-short-future-one' => 'in {0} yr.',
	'year-short-future-other' => 'in {0} yrs.',
	'year-short-past-one' => '{0} yr. ago',
	'year-short-past-other' => '{0} yrs. ago',
];
